@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 ###############################################################################
-# $Id: gdal_merge.py 27044 2014-03-16 23:41:27Z rouault $
+# $Id: gdal_merge.py 29213 2015-05-20 11:52:44Z rouault $
 #
 # Project:  InSAR Peppers
 # Purpose:  Module to extract data from many rasters into one output.
@@ -44,6 +44,7 @@ except:
 
 import sys
 import math
+import time
 
 __version__ = '$id$'[5:-1]
 verbose = 0
@@ -55,11 +56,19 @@ def raster_copy( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
                  t_fh, t_xoff, t_yoff, t_xsize, t_ysize, t_band_n,
                  nodata=None ):
 
-    if nodata is not None:
-        return raster_copy_with_nodata(
+    s_band = s_fh.GetRasterBand( s_band_n )
+    m_band = None
+    # Works only in binary mode and doesn't take into account
+    # intermediate transparency values for compositing
+    if s_band.GetMaskFlags() != gdal.GMF_ALL_VALID:
+        m_band = s_band.GetMaskBand()
+    elif s_band.GetColorInterpretation() == gdal.GCI_AlphaBand:
+        m_band = s_band
+    if m_band is not None:
+        return raster_copy_with_mask(
             s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
             t_fh, t_xoff, t_yoff, t_xsize, t_ysize, t_band_n,
-            nodata )
+            m_band )
 
     if verbose != 0:
         print('Copy %d,%d,%d,%d to %d,%d,%d,%d.' \
@@ -78,9 +87,9 @@ def raster_copy( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
     return 0
     
 # =============================================================================
-def raster_copy_with_nodata( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
-                             t_fh, t_xoff, t_yoff, t_xsize, t_ysize, t_band_n,
-                             nodata ):
+def raster_copy_with_mask( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
+                           t_fh, t_xoff, t_yoff, t_xsize, t_ysize, t_band_n,
+                           m_band ):
     try:
         import numpy as Numeric
     except ImportError:
@@ -96,10 +105,12 @@ def raster_copy_with_nodata( s_fh, s_xoff, s_yoff, s_xsize, s_ysize, s_band_n,
 
     data_src = s_band.ReadAsArray( s_xoff, s_yoff, s_xsize, s_ysize,
                                    t_xsize, t_ysize )
+    data_mask = m_band.ReadAsArray( s_xoff, s_yoff, s_xsize, s_ysize,
+                                    t_xsize, t_ysize )
     data_dst = t_band.ReadAsArray( t_xoff, t_yoff, t_xsize, t_ysize )
 
-    nodata_test = Numeric.equal(data_src,nodata)
-    to_write = Numeric.choose( nodata_test, (data_src, data_dst) )
+    mask_test = Numeric.equal(data_mask, 0)
+    to_write = Numeric.choose( mask_test, (data_src, data_dst) )
 
     t_band.WriteArray( to_write, t_xoff, t_yoff )
 
@@ -277,6 +288,7 @@ def main( argv=None ):
     band_type = None
     createonly = 0
     bTargetAlignedPixels = False
+    start_time = time.time()
     
     gdal.AllRegister()
     if argv is None:
@@ -486,9 +498,10 @@ def main( argv=None ):
         
         if verbose != 0:
             print("")
-            print("Processing file %5d of %5d, %6.3f%% completed." \
+            print("Processing file %5d of %5d, %6.3f%% completed in %d minutes." \
                   % (fi_processed+1,len(file_infos),
-                     fi_processed * 100.0 / len(file_infos)) )
+                     fi_processed * 100.0 / len(file_infos),
+                     int(round((time.time() - start_time)/60.0)) ))
             fi.report()
 
         if separate == 0 :
